@@ -19,6 +19,7 @@ void Audio::createWav(QString filename)
 {
     reader = new Reader();
     connect(reader, SIGNAL(finished()), this, SLOT(threadFinished()));
+    connect(reader,SIGNAL(destroyed()), this, SLOT(threadDeleted()));
 
     QString audio = filename;
     audio.chop(3);
@@ -50,6 +51,11 @@ void Audio::createWav(QString filename)
 
 }
 
+void Audio::threadDeleted()
+{
+    this->wavCreated();
+}
+
 void Audio::threadFinished()
 {
     music = Phonon::createPlayer(Phonon::MusicCategory,
@@ -61,8 +67,6 @@ void Audio::threadFinished()
     audioFile->close();
 
     reader->deleteLater();
-    this->wavCreated();
-
 }
 
 void Audio::audioFinished()
