@@ -136,15 +136,29 @@ void MainWindow::on_searchButton_clicked()
 void MainWindow::on_mainWindowButton_clicked()
 {
     if (!articleList->isVisible())
+    {
+        ui->mainWindowButton->setDown(true);
         articleList->show();
+    }
     else
+    {
         articleList->hide();
+        ui->mainWindowButton->setDown(false);
+    }
     if (playlist->isVisible())
+    {
+        ui->playlistsButton->setDown(false);
         playlist->hide();
+    }
     else if (player->isVisible())
+    {
         player->hide();
+        ui->playerButton->setDown(false);
+    }
     if (options->isVisible())
+    {
         options->hide();
+    }
     this->ui->label->hide();
     this->ui->label_2->hide();
 }
@@ -152,13 +166,25 @@ void MainWindow::on_mainWindowButton_clicked()
 void MainWindow::on_playlistsButton_clicked()
 {
     if (playlist->isVisible())
+    {
         playlist->hide();
+        ui->playlistsButton->setDown(false);
+    }
     else
+    {
         playlist->show();
+        ui->playlistsButton->setDown(true);
+    }
     if (articleList->isVisible())
+    {
         articleList->hide();
+        ui->mainWindowButton->setDown(false);
+    }
     else if (player->isVisible())
+    {
         player->hide();
+        ui->playerButton->setDown(false);
+    }
     if (options->isVisible())
         options->hide();
     this->ui->label->hide();
@@ -167,13 +193,25 @@ void MainWindow::on_playlistsButton_clicked()
 void MainWindow::on_playerButton_clicked()
 {
     if (player->isVisible())
+    {
         player->hide();
+        ui->playerButton->setDown(false);
+    }
     else
+    {
         player->show();
+        ui->playerButton->setDown(true);
+    }
     if (articleList->isVisible())
+    {
         articleList->hide();
+        ui->mainWindowButton->setDown(false);
+    }
     else if (playlist->isVisible())
+    {
         playlist->hide();
+        ui->playlistsButton->setDown(false);
+    }
     if (options->isVisible())
         options->hide();
     this->ui->label->hide();
@@ -237,7 +275,10 @@ void MainWindow::openArticleList(QList<QString> searchTitles)
 {
     articleList->fillTable(searchTitles, this->searchWord);
     if (!articleList->isVisible())
+    {
         articleList->show();
+        ui->mainWindowButton->setDown(true);
+    }
     message->hide();
 }
 
@@ -251,6 +292,7 @@ void MainWindow::openArticleInPlayer(QString title, QString article)
 {
      message->setLabelText("Processing " + title);
      player->openArticle(title, article);
+     ui->playerButton->setDown(true);
      player->show();
 
      //message->hide();
